==> openshift-model-console-6.8.0-sources.jar: io/fabric8/openshift/api/model/console/v1/CLIDownloadLinkFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CLIDownloadLinkFluent<A extends CLIDownloadLinkFluent<A>> extends BaseFluent<A>{
  public CLIDownloadLinkFluent() {
  }
  public CLIDownloadLinkFluent(CLIDownloadLink instance) {
    instance = (instance != null ? instance : new CLIDownloadLink());

    if (instance != null) {
      this.withHref(instance.getHref());
      this.withText(instance.getText());
      this.withHref(instance.getHref());
      this.withText(instance.getText());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String href;
  private String text;
  private Map<String,Object> additionalProperties;
  public String getHref() {
    return this.href;
  }
  public A withHref(String href) {
    this.href=href; return (A) this;
  }
  public boolean hasHref() {
    return this.href != null;
  }
  public String getText() {
    return this.text;
  }
  public A withText(String text) {
    this.text=text; return (A) this;
  }
  public boolean hasText() {
    return this.text != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CLIDownloadLinkFluent that = (CLIDownloadLinkFluent) o;
    if (!java.util.Objects.equals(href, that.href)) return false;

    if (!java.util.Objects.equals(text, that.text)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(href,  text,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (href != null) { sb.append("href:"); sb.append(href + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-console-6.9.0-sources.jar: io/fabric8/openshift/api/model/console/v1/CLIDownloadLinkFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CLIDownloadLinkFluent<A extends CLIDownloadLinkFluent<A>> extends BaseFluent<A>{
  public CLIDownloadLinkFluent() {
  }
  
  public CLIDownloadLinkFluent(CLIDownloadLink instance) {
    this.copyInstance(instance);
  }
  private String href;
  private String text;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(CLIDownloadLink instance) {
    instance = (instance != null ? instance : new CLIDownloadLink());
  
    if (instance != null) {
        this.withHref(instance.getHref());
        this.withText(instance.getText());
        this.withHref(instance.getHref());
        this.withText(instance.getText());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getHref() {
    return this.href;
  }
  
  public A withHref(String href) {
    this.href=href; return (A) this;
  }
  
  public boolean hasHref() {
    return this.href != null;
  }
  
  public String getText() {
    return this.text;
  }
  
  public A withText(String text) {
    this.text=text; return (A) this;
  }
  
  public boolean hasText() {
    return this.text != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CLIDownloadLinkFluent that = (CLIDownloadLinkFluent) o;
    if (!java.util.Objects.equals(href, that.href)) return false;
  
    if (!java.util.Objects.equals(text, that.text)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(href,  text,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (href != null) { sb.append("href:"); sb.append(href + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
